#' @encoding UTF-8
#' @title A Tool Set For Analyzing Political Behavior Data
#' @description Provides functions for analyzing political behavior data, including measures of political fragmentation, seats allocation, and graphical demonstrations.
#' @references Marcelino, Daniel (2013). \emph{SciencesPo: A Tool Set for Analyzing Political Behaviour Data}. Available at SSRN: \url{http://dx.doi.org/10.2139/ssrn.2320547}
#' @name SciencesPo
#' @docType package
#' @author Daniel Marcelino, \email{dmarcelino@@live.com}
#' @import parallel
#' @import methods
NULL

globalVariables("themes_data")
